import os
from comtypes.client import CoGetObject

class WMI(object):
    def __init__(self):
        self.__wmi = CoGetObject('winmgmts:')

    def instancesof(self, objecname:str):
        instances = []
        for instance in self.__wmi.InstancesOf(objecname):
            content = {}
            for prop in instance.Properties_:
                content[prop.Name] = prop.Value
            instances.append(content)
        return instances

    def get_harddisk_serial(self, drive_letter="C:"):
        for disk2partition in self.Win32_LogicalDiskToPartition_List():
            if disk2partition.get('Dependent','').split('"',1)[-1][:-1] != drive_letter: continue
            sysdiskindex = disk2partition.get('Antecedent','').split('"',1)[-1].split(',')[0][6:]
            for diskdrive in self.Win32_DiskDrive_List():
                if diskdrive.get('Index',-1) == int(sysdiskindex):
                    return diskdrive.get('SerialNumber', '')
            return ''

    def get_osharddisk_serial(self):
        return self.get_harddisk_serial(os.getenv('SystemDrive'))

    def Win32_LogicalDiskToPartition_List(self):
        return self.instancesof('Win32_LogicalDiskToPartition')

    def Win32_DiskDrive_List(self):
        return self.instancesof('Win32_DiskDrive')

    def Win32_Volume_List(self):
        return self.instancesof('Win32_Volume')

    def Win32_Process(self):
        return self.instancesof('Win32_Process')



from setuptools import setup

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='aclib.wmi',
    version='1.0.0',
    author='AnsChaser',
    author_email='anschaser@163.com',
    description='python wmi',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/AnsChaser/aclib.wmi',
    python_requires='>=3.6',
    install_requires=['comtypes'],
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ]
)
